Class: TranslationDiff::Passage::Scanner::Mark

Inherits:
Struct
  • Object
show all
Defined in:
lib/translation_diff/passage.rb

Overview

Where a run begins and whether it is prose; prose is set after the fact when an element claims protection.

Instance Attribute Summary collapse

Instance Attribute Details

#offset ⇒ Object

Returns the value of attribute offset

Returns:

  • (Object) —

    the current value of offset



42
43
44
# File 'lib/translation_diff/passage.rb', line 42

def offset
  @offset
end

#prose ⇒ Object

Returns the value of attribute prose

Returns:

  • (Object) —

    the current value of prose



42
43
44
# File 'lib/translation_diff/passage.rb', line 42

def prose
  @prose
end