Class: TranslationDiff::Previewer::Error

Inherits:
Error
  • Object
show all
Defined in:
lib/translation_diff/previewer.rb

Overview

Its own class, so rescuing a preview that cannot be answered cannot also swallow a cache or provider failure.