Class: TranslationDiff::Markup::Resolver
- Inherits:
-
Ox::Sax
- Object
- Ox::Sax
- TranslationDiff::Markup::Resolver
- Defined in:
- lib/translation_diff/markup.rb
Overview
Ox hands back the decoded text of the one element it was given; a name it does not know arrives as the text it was.
Instance Attribute Summary collapse
-
#text ⇒ Object
readonly
Returns the value of attribute text.
Instance Method Summary collapse
Instance Attribute Details
#text ⇒ Object (readonly)
Returns the value of attribute text.
81 82 83 |
# File 'lib/translation_diff/markup.rb', line 81 def text @text end |
Instance Method Details
#value(value) ⇒ Object
83 |
# File 'lib/translation_diff/markup.rb', line 83 def value(value) = @text = value.as_s |