Class: TranslationDiff::Passage::Scanner::Mark
- Inherits:
-
Struct
- Object
- Struct
- TranslationDiff::Passage::Scanner::Mark
- Defined in:
- lib/translation_diff/passage.rb
Overview
Where a run begins and whether it is prose; prose is set after the fact when an element claims protection.
Instance Attribute Summary collapse
-
#offset ⇒ Object
Returns the value of attribute offset.
-
#prose ⇒ Object
Returns the value of attribute prose.
Instance Attribute Details
#offset ⇒ Object
Returns the value of attribute offset
42 43 44 |
# File 'lib/translation_diff/passage.rb', line 42 def offset @offset end |
#prose ⇒ Object
Returns the value of attribute prose
42 43 44 |
# File 'lib/translation_diff/passage.rb', line 42 def prose @prose end |